@@ -1,4 +1,4 @@
-package Menus;
+package Term::Menus;
  
 #    Menus.pm
 #
@@ -23,7 +23,7 @@ use Exporter ();
 our @ISA = qw(Exporter);
 
 
-$VERSION = 1.08;
+$VERSION = 1.09;
 
 
 BEGIN {
